@@ -1,5 +1,7 @@
 /*
-© 2020 Red Hat, Inc.
+SPDX-License-Identifier: Apache-2.0
+
+Copyright Contributors to the Submariner project.
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -13,10 +15,12 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */
+
 package framework
 
 import (
 	"bytes"
+	"context"
 	"fmt"
 	"io"
 	"strconv"
@@ -130,7 +134,7 @@ func (np *NetworkPod) AwaitReady() {
 	pods := KubeClients[np.Config.Cluster].CoreV1().Pods(np.framework.Namespace)
 
 	np.Pod = AwaitUntil("await pod ready", func() (interface{}, error) {
-		return pods.Get(np.Pod.Name, metav1.GetOptions{})
+		return pods.Get(context.TODO(), np.Pod.Name, metav1.GetOptions{})
 	}, func(result interface{}) (bool, string, error) {
 		pod := result.(*v1.Pod)
 		if pod.Status.Phase != v1.PodRunning {
@@ -152,7 +156,7 @@ func (np *NetworkPod) AwaitFinishVerbose(verbose bool) {
 	pods := KubeClients[np.Config.Cluster].CoreV1().Pods(np.framework.Namespace)
 
 	_, np.TerminationErrorMsg, np.TerminationError = AwaitResultOrError(fmt.Sprintf("await pod %q finished", np.Pod.Name), func() (interface{}, error) {
-		return pods.Get(np.Pod.Name, metav1.GetOptions{})
+		return pods.Get(context.TODO(), np.Pod.Name, metav1.GetOptions{})
 	}, func(result interface{}) (bool, string, error) {
 		np.Pod = result.(*v1.Pod)
 
@@ -223,7 +227,7 @@ func (np *NetworkPod) RunCommand(cmd []string) (string, string) {
 func (np *NetworkPod) GetLog() string {
 	req := KubeClients[np.Config.Cluster].CoreV1().Pods(np.Pod.Namespace).GetLogs(np.Pod.Name, &v1.PodLogOptions{})
 
-	closer, err := req.Stream()
+	closer, err := req.Stream(context.TODO())
 	Expect(err).NotTo(HaveOccurred())
 	defer closer.Close()
 
@@ -270,7 +274,7 @@ func (np *NetworkPod) buildTCPCheckListenerPod() {
 
 	pc := KubeClients[np.Config.Cluster].CoreV1().Pods(np.framework.Namespace)
 	var err error
-	np.Pod, err = pc.Create(&tcpCheckListenerPod)
+	np.Pod, err = pc.Create(context.TODO(), &tcpCheckListenerPod, metav1.CreateOptions{})
 	Expect(err).NotTo(HaveOccurred())
 	np.AwaitReady()
 }
@@ -315,7 +319,7 @@ func (np *NetworkPod) buildTCPCheckConnectorPod() {
 
 	pc := KubeClients[np.Config.Cluster].CoreV1().Pods(np.framework.Namespace)
 	var err error
-	np.Pod, err = pc.Create(&tcpCheckConnectorPod)
+	np.Pod, err = pc.Create(context.TODO(), &tcpCheckConnectorPod, metav1.CreateOptions{})
 	Expect(err).NotTo(HaveOccurred())
 }
 
@@ -345,7 +349,7 @@ func (np *NetworkPod) buildThroughputClientPod() {
 						{Name: "TARGET_PORT", Value: strconv.Itoa(np.Config.Port)},
 						{Name: "CONN_TRIES", Value: strconv.Itoa(int(np.Config.ConnectionAttempts))},
 						{Name: "RETRY_SLEEP", Value: strconv.Itoa(int(np.Config.ConnectionTimeout))},
-						{Name: "CONN_TIMEOUT", Value: strconv.Itoa(int(np.Config.ConnectionTimeout*1000))},
+						{Name: "CONN_TIMEOUT", Value: strconv.Itoa(int(np.Config.ConnectionTimeout * 1000))},
 					},
 				},
 			},
@@ -354,7 +358,7 @@ func (np *NetworkPod) buildThroughputClientPod() {
 	}
 	pc := KubeClients[np.Config.Cluster].CoreV1().Pods(np.framework.Namespace)
 	var err error
-	np.Pod, err = pc.Create(&nettestPod)
+	np.Pod, err = pc.Create(context.TODO(), &nettestPod, metav1.CreateOptions{})
 	Expect(err).NotTo(HaveOccurred())
 	np.AwaitReady()
 }
@@ -388,7 +392,7 @@ func (np *NetworkPod) buildThroughputServerPod() {
 	}
 	pc := KubeClients[np.Config.Cluster].CoreV1().Pods(np.framework.Namespace)
 	var err error
-	np.Pod, err = pc.Create(&nettestPod)
+	np.Pod, err = pc.Create(context.TODO(), &nettestPod, metav1.CreateOptions{})
 	Expect(err).NotTo(HaveOccurred())
 	np.AwaitReady()
 }
@@ -425,7 +429,7 @@ func (np *NetworkPod) buildLatencyClientPod() {
 	}
 	pc := KubeClients[np.Config.Cluster].CoreV1().Pods(np.framework.Namespace)
 	var err error
-	np.Pod, err = pc.Create(&nettestPod)
+	np.Pod, err = pc.Create(context.TODO(), &nettestPod, metav1.CreateOptions{})
 	Expect(err).NotTo(HaveOccurred())
 	np.AwaitReady()
 }
@@ -456,7 +460,7 @@ func (np *NetworkPod) buildLatencyServerPod() {
 	}
 	pc := KubeClients[np.Config.Cluster].CoreV1().Pods(np.framework.Namespace)
 	var err error
-	np.Pod, err = pc.Create(&nettestPod)
+	np.Pod, err = pc.Create(context.TODO(), &nettestPod, metav1.CreateOptions{})
 	Expect(err).NotTo(HaveOccurred())
 	np.AwaitReady()
 }
@@ -464,6 +468,7 @@ func (np *NetworkPod) buildLatencyServerPod() {
 // create a test pod inside the current test namespace on the specified cluster.
 // The pod will use the image specified and run command specified.
 func (np *NetworkPod) buildCustomPod() {
+	terminationGracePeriodSeconds := int64(5)
 	customPod := v1.Pod{
 		ObjectMeta: metav1.ObjectMeta{
 			GenerateName: "custom",
@@ -472,8 +477,10 @@ func (np *NetworkPod) buildCustomPod() {
 			},
 		},
 		Spec: v1.PodSpec{
-			Affinity:      nodeAffinity(np.Config.Scheduling),
-			RestartPolicy: v1.RestartPolicyNever,
+			Affinity:                      nodeAffinity(np.Config.Scheduling),
+			RestartPolicy:                 v1.RestartPolicyNever,
+			HostNetwork:                   bool(np.Config.Networking),
+			TerminationGracePeriodSeconds: &terminationGracePeriodSeconds,
 			Containers: []v1.Container{
 				{
 					Name:            np.Config.ContainerName,
@@ -489,7 +496,7 @@ func (np *NetworkPod) buildCustomPod() {
 	pc := KubeClients[np.Config.Cluster].CoreV1().Pods(np.framework.Namespace)
 
 	var err error
-	np.Pod, err = pc.Create(&customPod)
+	np.Pod, err = pc.Create(context.TODO(), &customPod, metav1.CreateOptions{})
 	Expect(err).NotTo(HaveOccurred())
 
 	np.AwaitReady()
